/*
JMP Clinical Analytical Process

Name: Tree Map of Adverse Events
Authors: Geoff Mann and Russ Wolfinger, SAS Institute Inc.

Description: 
	This process creates a tree map of adverse events along
	with linked histograms of demographic variables and a data
	filter for rapid subsetting.
*/

/*
-----------------------------------------------------------
Copyright (C) 2009 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
*/

*ProcessVariables;

%global StudyName InPath AInPath TrtUse AEWhereStmt AESerOnly TEAEOnly IncSF PopulationSet IncFAS IncSAF IncITT IncPPROT IncCOMPL IncRAND IncENRL Concomitant OutPath ServerOutPath 
AETreeMap_OutData MacroPath AETreeMapScript;

*ProcessBody;

%macro AETreeMap;

*initialization and argument checking;
%let ProcessName = AETreeMap; 

%let Concomitant = No;

%include "&MacroPath./UtilityMacros.sas" / nosource;
%include "&MacroPath./CDISCParms.sas";
%if &exiterror %then %goto exit;

%AESerOnlyToAEWhereStmt;

%if %upcase(&TEAEOnly)=YES %then %do;
	data ae_te;
		set &in_ae;
	run;
	
	%TREATMENTEMERGENT(dataset = ae_te, domain = AE, date = AESTDTC);
	data ae_te;
		set ae_te;
		where _TRTEMRG = 1;
		drop _TRTEMRG;		
	run;
	
	%NObsVars(ae_te);
	%if ^&nobs %then %do;
		%put [MS_S_0051];
		%put ERROR: There are no Treatment Emergent Adverse Events.;
		%let exiterror = 1;
		%goto exit;
	%end;	
	%let in_ae = ae_te;
%end;		

%if %length(&AEWhereStmt) %then %do;
	data ae_ws;
		set &in_ae;
		where %unquote(&AEWhereStmt);
	run;
	%if &syserr > 4 %then %do;
		%put [MS_S_0019];
		%put ERROR: The specified filter &AEWhereStmt is invalid.  Change the filter to be valid for the domain you are considering.;
		%let exiterror = 1;
		%goto exit;
	%end;	
	%NObsVars(ae_ws);
	%if ^&nobs %then %do;
		%put [MS_S_0049];
		%put ERROR: No adverse events satisfy where statements or other filtering.;
		%let exiterror = 1;
		%goto exit;
	%end;		
	%let in_ae = ae_ws;
%end;	

data OutLib.ae;
	set &in_ae;
run;
data OutLib.adsl;
	set &in_adsl;
	%include "&MacroPath./TRTDURDY.sas";
run;
%if (&Concomitant=Yes) %then %do;
	data OutLib.cm;
		set &in_cm;
	run;
%end;	

* create Age Group if it does not exist;
%let _sid_ = %sysfunc(open(OutLib.adsl));
%let anum = %sysfunc(varnum(&_sid_, AGEGR1));
%let _rc_ = %sysfunc(close(&_sid_));
%if ^&anum %then %do;
	data OutLib.adsl;
		set OutLib.adsl;
		if      AGE < 10 then AGEGR1 = "000-009";
		else if AGE < 20 then AGEGR1 = "010-019";
		else if AGE < 30 then AGEGR1 = "020-029";
		else if AGE < 40 then AGEGR1 = "030-039";
		else if AGE < 50 then AGEGR1 = "040-049";
		else if AGE < 60 then AGEGR1 = "050-059";
		else if AGE < 70 then AGEGR1 = "060-069";
		else if AGE < 80 then AGEGR1 = "070-079";
		else if AGE < 90 then AGEGR1 = "080-089";
		else if AGE < 100 then AGEGR1 = "090-099";
		else if AGE < 110 then AGEGR1 = "100-109";
		else if AGE < 120 then AGEGR1 = "110-119";
		label AGEGR1="Age Group 1";
	run;
%end;

* get labels;
%let TermLabel = AEDECOD;
%CheckLabel(&in_ae,TermLabel);
%let BodyLabel = AEBODSYS;
%CheckLabel(&in_ae,BodyLabel);
%let CausalityLabel = AEREL;
%CheckLabel(&in_ae,CausalityLabel);
%let OutcomeLabel = AEOUT;
%CheckLabel(&in_ae,OutcomeLabel);
%if Concomitant = yes %then %do;
	%let CMLabel = CMDECOD
	%CheckLabel(&in_cm,CMLabel);
%end;

* severity variable;
%let _tid_ = %sysfunc(open(&in_ae));
%let svn = %sysfunc(varnum(&_tid_,AESEV));
%if ^&svn %then %do;
	%let svn = %sysfunc(varnum(&_tid_,AETOXGR));
	%if ^&svn %then %do;
		%put [MS_S_0047];
		%put ERROR: Either AESEV, ASEV, AETOXGR, or ATOXGR must be in the AE data set.;
		%let exiterror = 1;
	%end;
	%else %do;
		%let SeverityLabel = AETOXGR;
	%end;
%end;
%else %do;
	%let SeverityLabel = AESEV;
%end;
%let _tid_ = %sysfunc(close(&_tid_));
%if &exiterror %then %goto exit;
%CheckLabel(&in_ae,SeverityLabel);

* create JSL file;
%PrepOutFile(AETreeMapScript,AETreeMapScriptName,&StudyName &ProcessName..jsl);
%global _mainjslfile_ FullAPName;
%let _mainjslfile_ = &AETreeMapScript;
%let FullAPName=%str(AE Tree Map);

* put JSL statements;
data _null_;
   file "&AETreeMapScript" %if %nrbquote(&SYSENCODING) ne wlatin1 %then encoding="utf-8";;
	put "//!";
	
	put "Names Default to Here(1);";
	put "Here:DataList = {};";
	put "Here:TabButtonList = {};";
	put "Here:TabCodeList = {};";
	put "Here:TabAfterCodeList = {};";
	put "Here:TabOpenList = {};";
	
	put "sdtmFolder = ""&InPath"";";
	%if (&Concomitant=Yes) %then %do;
		put "addCMData = 1;";
	%end;
	%else %do;
		put "addCMData = 0;";
	%end;
	put "outFolder = ""&ClientOutPath"";";
	put "subjectLabel = ""&SubjectLabel"";";
	put "trtLabel = ""&TrtLabel"";";
	put "termLabel = ""&TermLabel"";";
	put "bodyLabel = ""&BodyLabel"";";
	put "severityLabel = ""&SeverityLabel"";";
	put "causalityLabel = ""&CausalityLabel"";";
	put "outcomeLabel = ""&OutcomeLabel"";";
	%if &Concomitant = yes %then %do;
		put "cmLabel = ""&CMLabel"";";
	%end;
   put "include(""$CLINICAL_HOME\JSLFiles\AE Tree Map.jsl"");";
run;

%if (&Concomitant=Yes) %then %do;
	%let dlist = "ae.sas7bdat, adsl.sas7bdat, cm.sas7bdat";
%end;
%else %do;
	%let dlist = "ae.sas7bdat, adsl.sas7bdat";
%end;

%PackageInsertFile(jsl code from &ProcessName, &OutPath, &AETreeMapScriptName, &dlist, yes);

%exit:;
%ExitSDSProcess(&OutPath, &ProcessName, &syserr, &exiterror, &clockrunning);

%mend AETreeMap;

* run the macro;
%AETreeMap;


